package Acme::Prereq::Itself;

use 5.006;
use strict;
use warnings;

=head1 NAME

Acme::Prereq::Itself - Module for testing CPAN module prerequisites

=head1 VERSION

Version 0.01

=cut

our $VERSION = '0.01';

1; # End of Acme::Prereq::Itself
